#!/usr/bin/env perl

=head1 DESCRIPTION

splitlines.pl - Simple Perl script to take incoming arbitrary text and output it in fixed-width lines, each at a user-specified length.

=head1 SYNOPSIS

  splitlines.pl [-f|--file <File to Read Input From>]
	  	[-l|-s|--length|--size <Size for Each String>]
		[<Size for Each String>]

=head1 OPTIONS

=head2 -f, --file <File to Read Input From>

Specifies the file to read input text from. The file at the specified path B<must> be readable by the current user running this script in order for this script to be able to parse its input into separate fixed-width lines.

=head2 -l, --length, -s, --size <Size for Each String>

Specifies the number of characters that should be in each outputted line.

=head1 ENVIRONMENT VARIABLES

This script supports the use of the following environment variables:

=head2 SPLITLINES_LINE_SIZE

Specifies the number of characters that should be in each outputted line, similar to -l or -s (or their long forms).

=head1 INPUTTING STRING SIZE

If the size for each string is not explicitly specified by a command-line option or command-line argument, the script will prompt the user to input it during the operation of splitting the arbitrary text.

=head1 AUTHOR

Jeffrey Meyer <jeffrey@thejeffrey.net>, 2016-2017

=cut

use strict;
use warnings;
use Getopt::Long;

my ($size,$file,$data);

Getopt::Long::Configure("bundling");
GetOptions(
	"l|s|length|size=s" => \$size,
	"f|file|input|i=s" => \$file,
);

sub prompt {
	print @_;
	my $in = <STDIN>;
	chomp $in;
}

BEGIN{
	$size = $ENV{SPLITLINES_LINE_SIZE} if($ENV{SPLITLINES_LINE_SIZE});
}

$size = prompt "Size for each string: " if(!$size);

($file) ? do{
	local $/ = undef;
	open FILE, $file or die "Cannot open $file: $!";
	$data = <FILE>;
	close FILE;
} : do{
	$data = '';
	$data .= $_ .= " " foreach(@ARGV);
};

my @r = ( $data =~ m/.{$size}/g );

print "$_\n" foreach(@r);
